/***************************************************/
/* Copyright (c) 2014 SAS Institute Inc.           */
/* SAS Campus Drive, Cary, NC, USA                 */
/* All Rights Reserved                             */
/***************************************************/

%macro getmetacreds();

   %global metacredsrc;
   %local MNAME;
   %let MNAME=getmetacreds;
   
   %local sasmetauser sasmetapwd sasmetahost sasmetaport;

   %let sasmetauser=%sysfunc(getoption(METAUSER));
   %let sasmetapwd=%sysfunc(getoption(METAPASS));
   %let sasmetahost=%sysfunc(getoption(METASERVER));
   %let sasmetaport=%sysfunc(getoption(METAPORT));

   %if  "&sasmetauser" ne "" and "sasmetapwd" ne "" and 
        "&sasmetahost" ne "" and "&sasmetaport" ne "" %then
   %do; /* some metadata credentials have been set */
      %if &evdebug > 1 %then %put DEBUG: (&MNAME) getoptions meta information set;
      %put NOTE: ***Macro GETMETACREDS: Metadata credentials already appear to be defined for this session%str(;) will use those credentials. ***;
      %put INFO: Current Metadata Credentials%str(/)Settings: ;
      
      proc options group=META;
      run;

      %let metacredsrc=SESSION;
      %goto EXIT;
   %end; /* some metadata credentials have been set */
   
   %else %do;   /* need to get credentials from agent prop file */
   	 %if %symexist(AGENTROOTDIR) eq 0 %then %getkeyprop(mvar=AGENTROOTDIR);
   	 %if %symexist(AGENTROOTDIR) eq 0 %then %do;
   	 	%goto ERROUT;
   	 %end;
      %let agentsasprops = %str(%trim(&agentrootdir)%trim(/conf/sas.properties));
      
      %if &evdebug > 1 %then %do;
      	%put DEBUG: (&MNAME) getting metadata info via sas.properties;
      	%put DEBUG: (&MNAME) path=[&agentsasprops];
      %end;
      
      %if %sysfunc(fileexist(&agentsasprops)) %then %do; 
          %if &evdebug > 1 %then %put DEBUG: (&MNAME) sas.properties fileexist test ok;
      %end;
      %else %do;
          %if &evdebug > 1 %then %put DEBUG: (&MNAME) sas.properties fileexist test failed;
          %put %sysfunc(sysmsg());
          %let agentsasprops=%str(NONE);
          %goto ERROUT;
      %end;
   %end;     /* of getting cred from agent prop file */
      
    /* load metadata connection info & credentials */
    %loadprops(propfile="&agentsasprops",prefix=sasmeta,scope=F);

    %if  "&sasmetauser" ne "" and "sasmetapwd" ne "" and 
         "&sasmetahost" ne "" and "&sasmetaport" ne "" %then
    %do; /* some metadata credentials have been set */
       %let metacredsrc=AGENT_PROPS;
       options metaserver="&sasmetahost" metaport=&sasmetaport metauser="&sasmetauser" metapass="&sasmetapwd";   
       %goto EXIT;
    %end;/* some metadata credentials have been set */
    
    %else %do;
       %put ERROR: (&MNAME) loadprops call failed to load metadata credentials;
       %goto ERROUT;
    %end;

 %ERROUT:
   %put ERROR: (&MNAME) No metadata credentials defined. You must set credentials; 
   %put ERROR: (&MNAME) explicitly if they cannot be obtained from the agent configuration.;
         
   %let metacredsrc=NONE;

 %EXIT:
  /* remove traces of the metadata password */
  %let sasmetapwd=x****x;

%mend getmetacreds;